<?php
/**
 * The template for displaying product content within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woothemes.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $product;


// Ensure visibility
if ( empty( $product ) || ! $product->is_visible() ) {
	return;
}
global $rocknrolla_theme_options;
$attachment_ids = $product->get_gallery_image_ids();
$catalog_mode = $rocknrolla_theme_options['rnr_shopproduct_catalog'];
$shop_columns = isset($_GET['shop_columns']) ? htmlspecialchars($_GET['shop_columns']) : get_option('woocommerce_catalog_columns');

switch($shop_columns) {
	case '2':
		$columns = 'rnr-col-1-2';
		break;
	case '3':
		$columns = 'rnr-col-1-3';
		break;
	case '4':
		$columns = 'rnr-col-1-4';
		break;	
	case '5':
		$columns = 'rnr-col-1-5';
		break;
	case '6':
		$columns = 'rnr-col-1-6';
		break;
}
?>

<article itemscope itemtype="product" <?php post_class("post item ".$columns." "); ?>>
	<?php
		$image_html = "";

		if ( has_post_thumbnail() ) {
			$image_html = wp_get_attachment_image( get_post_thumbnail_id(), 'shop_catalog' );					
		} else if ( wc_placeholder_img_src() ) {
			$image_html = wc_placeholder_img( 'shop_catalog' );
		}
	?>
	<figure class="product-image">
		<?php do_action( 'rnr_product_badge'); ?>
		<?php echo rnr_wishlist_button(); ?>
		<?php 
			if ($attachment_ids) {
					
					echo '<a href="'.get_the_permalink().'" title="'. the_title_attribute(array('echo' => 0)).'" class="fade">'.$image_html.'</a>';	

					if ( ! get_post_meta( $attachment_ids[0], '_woocommerce_exclude_image', true ) ) { 
						echo '<a href="'.get_the_permalink().'" title="'. the_title_attribute(array('echo' => 0)).'" class="fade">'.wp_get_attachment_image( $attachment_ids[0], 'shop_catalog' ).'</a>';	
					}
								
			} else {
					echo '<a href="'.get_the_permalink().'" title="'. the_title_attribute(array('echo' => 0)).'">'.$image_html.'</a>';	
			}
		?>
		<?php if ($catalog_mode != true) { wc_get_template( 'loop/add-to-cart.php' ); } ?>
	</figure>
	<header class="post-title<?php if ($catalog_mode == true) { echo ' catalog-mode'; } ?>">
		<h5><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></h5>
		<?php if ($catalog_mode != true) { ?>
			<?php
				/**
				 * woocommerce_after_shop_loop_item_title hook
				 *
				 * @hooked woocommerce_template_loop_price - 10
				 */
				do_action( 'woocommerce_after_shop_loop_item_title' );
			?>
			<?php do_action( 'woocommerce_after_shop_loop_item' ); ?>
		<?php } ?>
	</header>
	
</article><!-- end product -->